@@ -1,6 +1,6 @@
 package Catmandu::Fix::Bind::pica_each;
 
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 
 use Moo;
 use Catmandu::Sane;
@@ -26,26 +26,24 @@ sub unit {
 
 sub bind {
     my ( $self, $data, $code ) = @_;
-    return if reftype( $data->{record} ) ne 'ARRAY';
+    return $data if $self->done or reftype( $data->{record} ) ne 'ARRAY';
 
-    return $data if $self->done;
-
-    my $fields = $data->{record} // [];
-
-    if ( $self->pica_path ) {
-        @$fields = grep { $self->pica_path->match_field($_) } @{$fields};
-    }
+    my $fields = $data->{record};
 
     my @new = ();
 
     for my $field ( @{$fields} ) {
+        if ( $self->pica_path && !$self->pica_path->match_field($field) ) {
+            push @new, $field;
+        }
+        else {
+            $data->{record} = [$field];
 
-        $data->{record} = [$field];
+            my $fixed = $code->($data);
 
-        my $fixed = $code->($data);
-
-        push @new, @{ $fixed->{record} }
-          if defined($fixed) && exists $fixed->{record};
+            push @new, @{ $fixed->{record} }
+              if defined($fixed) && exists $fixed->{record};
+        }
     }
 
     $data->{record} = \@new if exists $data->{record};
@@ -72,13 +70,6 @@ Catmandu::Fix::Bind::pica_each - a binder that loops over PICA fields
         end
     end
 
-    # Delete all the 041A subject fields
-    do pica_each()
-        if pica_match("041A",".*")
-            reject()
-        end
-    end
-
     do pica_each("0...")
         # process only level 0 fields
     end
